@@ -10,7 +10,7 @@ $SIG{'QUIT'} = sub { exec('reset'); };
 $SIG{'INT'}  = sub { exec('reset'); };
 $SIG{'KILL'} = sub { exec('reset'); };
 
-my $args = join('',@ARGV);
+my $args = join('', @ARGV);
 
 my $dev = 0;
 if ($args =~ /(\d+)/) {
@@ -24,77 +24,77 @@ $f[1] = Graphics::Framebuffer->new('FILE_MODE' => 1, 'FB_DEVICE' => "/dev/fb$dev
 
 $f[0]->cls('OFF');
 my @t;
-my $x     = $f[0]->{'XRES'} / 2;
-my $y     = $f[0]->{'YRES'} / 2;
+my $x        = $f[0]->{'XRES'} / 2;
+my $y        = $f[0]->{'YRES'} / 2;
 my $max_time = 10;
 my $master;
 my $count;
 
-foreach $count (0..1) {
+foreach $count (0 .. 1) {
     $f[$count]->cls();
     my $bench = 0;
     my $start = time + $max_time;
     $master = int(rand(16777216));
-    while(time<$start) {
+    while (time < $start) {
         $f[$count]->set_color(ncolor());
-        $f[$count]->circle({'x' => $x, 'y' => $y, 'radius' => $y - 1, 'filled' => 1});
+        $f[$count]->circle({ 'x' => $x, 'y' => $y, 'radius' => $y - 1, 'filled' => 1 });
         $bench++;
     }
 
     push(@t, $bench);
-}
-foreach $count (0..1) {
+} ## end foreach $count (0 .. 1)
+foreach $count (0 .. 1) {
     $f[$count]->cls();
     my $bench = 0;
     my $start = time + $max_time;
     $master = int(rand(16777216));
-    while (time<$start) {
-            $f[$count]->set_color(ncolor());
-            $f[$count]->box({'x' => 0, 'y' => 0, 'xx' => $f[0]->{'XRES'} , 'yy' => $f[0]->{'YRES'}, 'filled' => 1});
-            $bench++;
+    while (time < $start) {
+        $f[$count]->set_color(ncolor());
+        $f[$count]->box({ 'x' => 0, 'y' => 0, 'xx' => $f[0]->{'XRES'}, 'yy' => $f[0]->{'YRES'}, 'filled' => 1 });
+        $bench++;
     }
 
     push(@t, $bench);
-}
-foreach $count (0..1) {
+} ## end foreach $count (0 .. 1)
+foreach $count (0 .. 1) {
     $f[$count]->cls();
     my $bench = 0;
     my $start = time + $max_time;
     $master = int(rand(16777216));
-    while (time<$start) {
+    while (time < $start) {
         $f[$count]->set_color(ncolor());
-        $f[$count]->line({'x' => 0, 'y' => 0, 'xx' => $f[0]->{'XRES'}, 'yy' => $f[0]->{'YRES'}});
+        $f[$count]->line({ 'x' => 0, 'y' => 0, 'xx' => $f[0]->{'XRES'}, 'yy' => $f[0]->{'YRES'} });
         $bench++;
     }
     push(@t, $bench);
-}
+} ## end foreach $count (0 .. 1)
 
 $f[0]->cls('ON');
-my @names = ('CIRCLE','CIRCLE','   BOX','   BOX','  LINE','  LINE');
+my @names = ('CIRCLE', 'CIRCLE', '   BOX', '   BOX', '  LINE', '  LINE');
 print STDERR "The higher the number, the faster it is.\n\n";
 
 my $file_average   = 0;
 my $string_average = 0;
-for (my $idx=0;$idx<6;$idx+=2) {
-    if ($t[$idx] > $t[$idx+1]) {
-        print STDERR sprintf('%s MMAP:  %d (fastest)',$names[$idx],$t[$idx]),"\n";
-        print STDERR sprintf('%s FILE:  %d',$names[$idx+1],$t[$idx+1]),"\n\n";
-    } elsif ($t[$idx] < $t[$idx+1]) {
-        print STDERR sprintf('%s MMAP:  %d',$names[$idx],$t[$idx]),"\n";
-        print STDERR sprintf('%s FILE:  %d (fastest)',$names[$idx+1],$t[$idx+1]),"\n\n";
+for (my $idx = 0; $idx < 6; $idx += 2) {
+    if ($t[$idx] > $t[$idx + 1]) {
+        print STDERR sprintf('%s MMAP:  %d (fastest)', $names[$idx], $t[$idx]), "\n";
+        print STDERR sprintf('%s FILE:  %d', $names[$idx + 1], $t[$idx + 1]), "\n\n";
+    } elsif ($t[$idx] < $t[$idx + 1]) {
+        print STDERR sprintf('%s MMAP:  %d', $names[$idx], $t[$idx]), "\n";
+        print STDERR sprintf('%s FILE:  %d (fastest)', $names[$idx + 1], $t[$idx + 1]), "\n\n";
     } else {
-        print STDERR sprintf('%s MMAP:  %d',$names[$idx],$t[$idx]),"\n";
-        print STDERR sprintf('%s FILE:  %d',$names[$idx+1],$t[$idx+1]),"\n\n";
+        print STDERR sprintf('%s MMAP:  %d', $names[$idx], $t[$idx]), "\n";
+        print STDERR sprintf('%s FILE:  %d', $names[$idx + 1], $t[$idx + 1]), "\n\n";
     }
     $string_average += $t[$idx];
-    $file_average   += $t[$idx+1];
-}
+    $file_average   += $t[$idx + 1];
+} ## end for (my $idx = 0; $idx ...)
 
 $file_average   /= 3;
 $string_average /= 3;
 
-print STDERR sprintf('Memory Mapped String Mode Average: %.03f',$string_average),"\n";
-print STDERR sprintf('         File Handle Mode Average: %.03f',$file_average),"\n\n";
+print STDERR sprintf('Memory Mapped String Mode Average: %.03f', $string_average), "\n";
+print STDERR sprintf('         File Handle Mode Average: %.03f', $file_average),   "\n\n";
 
 if ($file_average <= $string_average) {
     print STDERR "It is recommended you use the default Mmap string mode for your framebuffer device.\n";
@@ -103,11 +103,11 @@ if ($file_average <= $string_average) {
 }
 
 sub ncolor {
-    my $temp = pack('L',$master);
-    my ($red,$green,$blue) = unpack('C3',$temp);
-    $master+=8;
-    return({'red'=>$red,'green'=>$green,'blue'=>$blue});
-}
+    my $temp = pack('L', $master);
+    my ($red, $green, $blue) = unpack('C3', $temp);
+    $master += 8;
+    return ({ 'red' => $red, 'green' => $green, 'blue' => $blue });
+} ## end sub ncolor
 
 =head1 NAME
 
