@@ -61,8 +61,8 @@ my $xm       = $F->{'XRES'} / 1920;
 my $ym       = $F->{'YRES'} / 1080;
 my $XX       = $screen_width;
 my $YY       = $screen_height;
-my $center_x = $XX / 2;
-my $center_y = $YY / 2;
+my $center_x = $F->{'X_CLIP'} + ($F->{'W_CLIP'} / 2);
+my $center_y = $F->{'Y_CLIP'} + ($F->{'H_CLIP'} / 2);
 my $factor   = 3;
 my $rpi      = ($F->{'fscreeninfo'}->{'id'} =~ /BCM270(8|9)/i) ? 1 : 0;
 
@@ -133,19 +133,14 @@ hatch_filled_ellipses();
 hatch_filled_pies();
 hatch_filled_polygons();
 
-vertical_gradient_boxes();
-vertical_gradient_rounded_boxes();
-vertical_gradient_circles();
-vertical_gradient_ellipses();
-vertical_gradient_pies();
-vertical_gradient_polygons();
-
-horizontal_gradient_boxes();
-horizontal_gradient_rounded_boxes();
-horizontal_gradient_circles();
-horizontal_gradient_ellipses();
-horizontal_gradient_pies();
-horizontal_gradient_polygons();
+foreach my $d (qw(vertical horizontal)) {
+    gradient_boxes($d);
+    gradient_rounded_boxes($d);
+    gradient_circles($d);
+    gradient_ellipses($d);
+    gradient_pies($d);
+    gradient_polygons($d);
+}
 
 texture_filled_boxes();
 texture_filled_rounded_boxes();
@@ -277,7 +272,7 @@ sub angle_lines {
     my $angle = 0;
     while (time < $s) {
         $F->set_color({ 'red' => int(rand(256)), 'green' => int(rand(256)), 'blue' => int(rand(256)) });
-        $F->angle_line({ 'x' => $center_x, 'y' => $center_y, 'radius' => ($center_y - $F->{'Y_CLIP'}), 'angle' => $angle, 'antialiased' => $aa });
+        $F->angle_line({ 'x' => $center_x, 'y' => $center_y, 'radius' => int($F->{'H_CLIP'} / 2), 'angle' => $angle, 'antialiased' => $aa });
 	    $angle += 1.1;
         $angle -= 360 if ($angle >= 360);
     } ## end while (time < $s)
@@ -305,9 +300,9 @@ sub filled_boxes {
     }
 } ## end sub filled_boxes
 
-sub vertical_gradient_boxes {
-    
-    print_it($F, 'Vertical Gradient Box Test');
+sub gradient_boxes {
+    my $direction = shift;
+    print_it($F, ucfirst($direction) . ' Gradient Box Test');
     my $s = time + $factor;
     while (time < $s) {
         my $x  = int(rand($XX));
@@ -330,6 +325,7 @@ sub vertical_gradient_boxes {
                 'yy'       => $yy,
                 'filled'   => 1,
                 'gradient' => {
+                    'direction' => $direction,
                     'colors' => {
                         'red'   => \@red,
                         'green' => \@green,
@@ -370,46 +366,6 @@ sub hatch_filled_boxes {
     $F->attribute_reset();
 } ## end sub hatch_filled_boxes
 
-sub horizontal_gradient_boxes {
-    
-    print_it($F, 'Horizontal Gradient Box Test');
-
-    my $s = time + $factor;
-    while (time < $s) {
-        my $x  = int(rand($XX));
-        my $xx = int(rand($XX));
-        my $y  = int(rand($YY));
-        my $yy = int(rand($YY));
-        my $w  = max($xx, $x) - min($xx, $x);
-        my $h  = max($yy, $y) - min($yy, $y);
-        next if ($w < 10 || $h < 10);
-        my $count = min($w, int(rand(10)) + 2);
-        my @red   = map { $_ = int(rand(256)) } (1 .. $count);
-        my @green = map { $_ = int(rand(256)) } (1 .. $count);
-        my @blue  = map { $_ = int(rand(256)) } (1 .. $count);
-
-        $F->box(
-            {
-                'x'        => $x,
-                'y'        => $y,
-                'xx'       => $xx,
-                'yy'       => $yy,
-                'filled'   => 1,
-                'gradient' => {
-                    'direction' => 'horizontal',
-                    'colors'    => {
-                        'red'   => \@red,
-                        'green' => \@green,
-                        'blue'  => \@blue,
-                    }
-                }
-            }
-        );
-
-        #        print STDERR Dumper(\@red),Dumper(\@green),Dumper(\@blue),"C=$count,W=$w\n";sleep 5;
-    } ## end while (time < $s)
-} ## end sub horizontal_gradient_boxes
-
 sub texture_filled_boxes {
     
     print_it($F, 'Texture Filled Box Test');
@@ -465,9 +421,9 @@ sub hatch_filled_rounded_boxes {
     $F->attribute_reset();
 } ## end sub hatch_filled_rounded_boxes
 
-sub vertical_gradient_rounded_boxes {
-    
-    print_it($F, 'Vertical Gradient Rounded Box Test');
+sub gradient_rounded_boxes {
+    my $direction = shift;
+    print_it($F, ucfirst($direction) . ' Gradient Rounded Box Test');
 
     my $s = time + $factor;
     while (time < $s) {
@@ -493,6 +449,7 @@ sub vertical_gradient_rounded_boxes {
                 'radius'   => 4 + rand($XX / 16),
                 'filled'   => 1,
                 'gradient' => {
+                    'direction' => $direction,
                     'colors' => {
                         'red'   => \@red,
                         'green' => \@green,
@@ -504,46 +461,6 @@ sub vertical_gradient_rounded_boxes {
     } ## end while (time < $s)
 } ## end sub vertical_gradient_rounded_boxes
 
-sub horizontal_gradient_rounded_boxes {
-    
-    print_it($F, 'Horizontal Gradient Rounded Box Test');
-
-    my $s = time + $factor;
-    while (time < $s) {
-
-        #        $F->set_color({ 'red' => int(rand(256)), 'green' => int(rand(256)), 'blue' => int(rand(256)) });
-        my $x  = int(rand($XX));
-        my $xx = int(rand($XX));
-        my $y  = int(rand($YY));
-        my $yy = int(rand($YY));
-        my $w  = max($xx, $x) - min($xx, $x);
-        my $h  = max($yy, $y) - min($yy, $y);
-        next if ($w < 10 || $h < 10);
-        my $count = min($w, int(rand(10)) + 2);
-        my @red   = map { $_ = int(rand(256)) } (1 .. $count);
-        my @green = map { $_ = int(rand(256)) } (1 .. $count);
-        my @blue  = map { $_ = int(rand(256)) } (1 .. $count);
-        $F->box(
-            {
-                'x'        => $x,
-                'y'        => $y,
-                'xx'       => $xx,
-                'yy'       => $yy,
-                'radius'   => 4 + rand($XX / 16),
-                'filled'   => 1,
-                'gradient' => {
-                    'direction' => 'horizontal',
-                    'colors'    => {
-                        'red'   => \@red,
-                        'green' => \@green,
-                        'blue'  => \@blue,
-                    }
-                }
-            }
-        );
-    } ## end while (time < $s)
-} ## end sub horizontal_gradient_rounded_boxes
-
 sub texture_filled_rounded_boxes {
     
     print_it($F, 'Texture Filled Rounded Box Test');
@@ -600,9 +517,9 @@ sub hatch_filled_circles {
     $F->attribute_reset();
 } ## end sub hatch_filled_circles
 
-sub vertical_gradient_circles {
-    
-    print_it($F, 'Vertical Gradient Circle Test');
+sub gradient_circles {
+    my $direction = shift;
+    print_it($F, ucfirst($direction) . ' Gradient Circle Test');
 
     my $s = time + $factor;
     while (time < $s) {
@@ -622,6 +539,7 @@ sub vertical_gradient_circles {
                 'radius'   => $r,
                 'filled'   => 1,
                 'gradient' => {
+                    'direction' => $direction,
                     'colors' => {
                         'red'   => \@red,
                         'green' => \@green,
@@ -633,40 +551,6 @@ sub vertical_gradient_circles {
     } ## end while (time < $s)
 } ## end sub vertical_gradient_circles
 
-sub horizontal_gradient_circles {
-    
-    print_it($F, 'Horizontal Gradient Circle Test');
-
-    my $s = time + $factor;
-    while (time < $s) {
-
-        #        $F->set_color({ 'red' => int(rand(256)), 'green' => int(rand(256)), 'blue' => int(rand(256)) });
-        my $x     = int(rand($XX));
-        my $r     = int(rand($center_y) + 10);
-        my $w     = $r * 2;
-        my $count = min($w, int(rand(10)) + 2);
-        my @red   = map { $_ = int(rand(256)) } (1 .. $count);
-        my @green = map { $_ = int(rand(256)) } (1 .. $count);
-        my @blue  = map { $_ = int(rand(256)) } (1 .. $count);
-        $F->circle(
-            {
-                'x'        => $x,
-                'y'        => int(rand($YY)),
-                'radius'   => $r,
-                'filled'   => 1,
-                'gradient' => {
-                    'direction' => 'horizontal',
-                    'colors'    => {
-                        'red'   => \@red,
-                        'green' => \@green,
-                        'blue'  => \@blue,
-                    }
-                }
-            }
-        );
-    } ## end while (time < $s)
-} ## end sub horizontal_gradient_circles
-
 sub texture_filled_circles {
     
     print_it($F, 'Texture Filled Circle Test');
@@ -731,9 +615,9 @@ sub hatch_filled_pies {
     $F->attribute_reset();
 } ## end sub hatch_filled_pies
 
-sub vertical_gradient_pies {
-    
-    print_it($F, 'Vertical Gradient Filled Pie Test');
+sub gradient_pies {
+    my $direction = shift;
+    print_it($F, ucfirst($direction) . ' Gradient Filled Pie Test');
 
     my $s = time + $factor;
     while (time < $s) {
@@ -752,6 +636,7 @@ sub vertical_gradient_pies {
                 'start_degrees' => rand(360),
                 'end_degrees'   => rand(360),
                 'gradient'      => {
+                    'direction' => $direction,
                     'colors' => {
                         'red'   => \@red,
                         'green' => \@green,
@@ -763,41 +648,6 @@ sub vertical_gradient_pies {
     } ## end while (time < $s)
 } ## end sub vertical_gradient_pies
 
-sub horizontal_gradient_pies {
-    
-    print_it($F, 'Horizontal Gradient Filled Pie Test');
-
-    my $s = time + $factor;
-    while (time < $s) {
-
-        #        $F->set_color({ 'red' => int(rand(256)), 'green' => int(rand(256)), 'blue' => int(rand(256)) });
-        my $x     = int(rand($XX));
-        my $r     = int(rand($center_y) + 10);
-        my $w     = $r * 2;
-        my $count = min($w, int(rand(10)) + 2);
-        my @red   = map { $_ = int(rand(256)) } (1 .. $count);
-        my @green = map { $_ = int(rand(256)) } (1 .. $count);
-        my @blue  = map { $_ = int(rand(256)) } (1 .. $count);
-        $F->filled_pie(
-            {
-                'x'             => $x,
-                'y'             => int(rand($YY)),
-                'radius'        => $r,
-                'start_degrees' => rand(360),
-                'end_degrees'   => rand(360),
-                'gradient'      => {
-                    'direction' => 'horizontal',
-                    'colors'    => {
-                        'red'   => \@red,
-                        'green' => \@green,
-                        'blue'  => \@blue,
-                    }
-                }
-            }
-        );
-    } ## end while (time < $s)
-} ## end sub horizontal_gradient_pies
-
 sub texture_filled_pies {
     
     print_it($F, 'Texture Filled Pie Test');
@@ -857,9 +707,9 @@ sub hatch_filled_ellipses {
     $F->attribute_reset();
 } ## end sub hatch_filled_ellipses
 
-sub vertical_gradient_ellipses {
-    
-    print_it($F, 'Vertical Gradient Ellipse Test');
+sub gradient_ellipses {
+    my $direction = shift;
+    print_it($F, ucfirst($direction) . ' Gradient Ellipse Test');
 
     my $s = time + $factor;
     while (time < $s) {
@@ -877,6 +727,7 @@ sub vertical_gradient_ellipses {
                 'yradius'  => $rh,
                 'filled'   => 1,
                 'gradient' => {
+                    'direction' => $direction,
                     'colors' => {
                         'red'   => \@red,
                         'green' => \@green,
@@ -888,38 +739,6 @@ sub vertical_gradient_ellipses {
     } ## end while (time < $s)
 } ## end sub vertical_gradient_ellipses
 
-sub horizontal_gradient_ellipses {
-    
-    print_it($F, 'Horizontal Gradient Ellipse Test');
-
-    my $s = time + $factor;
-    while (time < $s) {
-        my $rw    = int(rand($center_x) + 10);
-        my $w     = $rw * 2;
-        my $count = min($w, int(rand(10)) + 2);
-        my @red   = map { $_ = int(rand(256)) } (1 .. $count);
-        my @green = map { $_ = int(rand(256)) } (1 .. $count);
-        my @blue  = map { $_ = int(rand(256)) } (1 .. $count);
-        $F->ellipse(
-            {
-                'x'        => int(rand($XX)),
-                'y'        => int(rand($YY)),
-                'xradius'  => $rw,
-                'yradius'  => rand($center_y),
-                'filled'   => 1,
-                'gradient' => {
-                    'direction' => 'horizontal',
-                    'colors'    => {
-                        'red'   => \@red,
-                        'green' => \@green,
-                        'blue'  => \@blue,
-                    }
-                }
-            }
-        );
-    } ## end while (time < $s)
-} ## end sub horizontal_gradient_ellipses
-
 sub texture_filled_ellipses {
     
     print_it($F, 'Image Filled Ellipse Test');
@@ -1011,9 +830,9 @@ sub hatch_filled_polygons {
     $F->attribute_reset();
 } ## end sub hatch_filled_polygons
 
-sub vertical_gradient_polygons {
-    
-    print_it($F, 'Vertical Gradient Polygon Test');
+sub gradient_polygons {
+    my $direction = shift;
+    print_it($F, ucfirst($direction) . ' Gradient Polygon Test');
 
     my $s = time + $factor;
     while (time < $s) {
@@ -1031,6 +850,7 @@ sub vertical_gradient_polygons {
                 'coordinates' => $coords,
                 'filled'      => 1,
                 'gradient'    => {
+                    'direction' => $direction,
                     'colors' => {
                         'red'   => \@red,
                         'green' => \@green,
@@ -1042,38 +862,6 @@ sub vertical_gradient_polygons {
     } ## end while (time < $s)
 } ## end sub vertical_gradient_polygons
 
-sub horizontal_gradient_polygons {
-    
-    print_it($F, 'Horizontal Gradient Polygon Test');
-
-    my $s = time + $factor;
-    while (time < $s) {
-        my $count  = int(rand(10)) + 2;
-        my @red    = map { $_ = int(rand(256)) } (1 .. $count);
-        my @green  = map { $_ = int(rand(256)) } (1 .. $count);
-        my @blue   = map { $_ = int(rand(256)) } (1 .. $count);
-        my $points = int(rand(2)) + 3;
-        my $coords = [];
-        foreach my $p (1 .. $points) {
-            push(@{$coords}, int(rand($XX)), int(rand($YY)));
-        }
-        $F->polygon(
-            {
-                'coordinates' => $coords,
-                'filled'      => 1,
-                'gradient'    => {
-                    'direction' => 'horizontal',
-                    'colors'    => {
-                        'red'   => \@red,
-                        'green' => \@green,
-                        'blue'  => \@blue,
-                    }
-                }
-            }
-        );
-    } ## end while (time < $s)
-} ## end sub horizontal_gradient_polygons
-
 sub texture_filled_polygons {
     
     print_it($F, 'Texture Filled Polygon Test');
