@@ -71,6 +71,7 @@ use constant {
 };
 
 use POSIX ();
+use POSIX qw(modf);
 use List::Util qw(min max);
 
 # use Inline (Config => directory => './.Graphics-Framebuffer-Inline');
@@ -706,7 +707,7 @@ END_C
 
 BEGIN {
     require Exporter;
-    our $VERSION = 1.02;
+    our $VERSION = 1.03;
     our @EXPORT_OK = qw(c_monochrome c_convert_16_24 c_convert_24_16 c_get_screen_info c_plot c_line c_blit_write c_flip_vertical c_flip_horizontal c_rotate );
     our @EXPORT    = qw( $INLINE );
 }
@@ -2034,7 +2035,7 @@ sub _draw_line_antialiased {
     # handle the endpoints
     foreach my $xy ([$x0, $y0], [$x1, $y1]) {
         my ($x, $y) = @{$xy};
-        my $xend    = POSIX::lround($x);
+        my $xend    = int($x + 0.5); # POSIX::lround($x);
         my $yend    = $y + $gradient * ($xend - $x);
         my $xgap    = _rfpart($x + 0.5);
 
