@@ -48,7 +48,7 @@ sub _perl_logo {
         $self->ttf_print(
             {
                 'bounding_box' => TRUE,
-                'y'            => 85 * $vf,
+                'y'            => 126 * $vf, # 85 * $vf,
                 'height'       => 80 * $vf,
                 'wscale'       => 1,
                 'color'        => '0040FFFF',
@@ -187,7 +187,7 @@ sub splash {
                 {
                     'bounding_box' => TRUE,
                     'x'            => (75  * $hf) + $X,
-                    'y'            => (50  * $vf) + $Y,
+                    'y'            => (70  * $vf) + $Y,
                     'height'       => 37.5 * $vf,
                     'wscale'       => 2,
                     'color'        => $color,
@@ -219,7 +219,7 @@ sub splash {
                 {
                     'bounding_box' => TRUE,
                     'x'            => 0,
-                    'y'            => (50  * $vf) + $Y,
+                    'y'            => (70  * $vf) + $Y,
                     'height'       => 37.5 * $vf,
                     'wscale'       => 2,
                     'color'        => $color,
@@ -251,7 +251,7 @@ sub splash {
                 {
                     'bounding_box' => TRUE,
                     'x'            => (190 * $hf) + $X,
-                    'y'            => (50  * $vf) + $Y,
+                    'y'            => (70  * $vf) + $Y,
                     'height'       => 37.5 * $vf,
                     'wscale'       => 2,
                     'color'        => $color,
@@ -267,7 +267,7 @@ sub splash {
             {
                 'bounding_box' => TRUE,
                 'x'            => 0,
-                'y'            => (100 * $vf) + $Y,
+                'y'            => (130 * $vf) + $Y,
                 'height'       => 42   * $vf,
                 'wscale'       => 1,
                 'color'        => 'FFFF00FF',
@@ -288,7 +288,7 @@ sub splash {
                 {
                     'bounding_box' => TRUE,
                     'x'            => 0,
-                    'y'            => (140 * $vf) + $Y,
+                    'y'            => (170 * $vf) + $Y,
                     'height'       => 38   * $vf,
                     'wscale'       => 1,
                     'color'        => 'FFFFFFFF',
@@ -305,7 +305,7 @@ sub splash {
             {
                 'bounding_box' => TRUE,
                 'x'            => 0,
-                'y'            => (190 * $vf) + $Y,
+                'y'            => (220 * $vf) + $Y,
                 'height'       => 48   * $vf,
                 'wscale'       => 1,
                 'color'        => 'FFFFFFFF',
@@ -603,7 +603,7 @@ sub splash {
                     {
                         'bounding_box' => TRUE,
                         'x'            => (510 * $hf) + $X,
-                        'y'            => (300 * $vf) + $Y,
+                        'y'            => (351 * $vf) + $Y,
                         'height'       => 110  * $vf,
                         'wscale'       => 1.5,
                         'color'        => '00FFFFFF',
@@ -620,7 +620,7 @@ sub splash {
                 {
                     'bounding_box' => TRUE,
                     'x'            => 0,
-                    'y'            => (560 * $vf) + $Y,
+                    'y'            => (641 * $vf) + $Y,
                     'height'       => 200  * $vf,
                     'wscale'       => 1,
                     'color'        => '221100FF',
@@ -644,7 +644,7 @@ sub splash {
             {
                 'bounding_box' => TRUE,
                 'x'            => 0,
-                'y'            => (560 * $vf) + $Y,
+                'y'            => (641 * $vf) + $Y,
                 'height'       => 200  * $vf,
                 'wscale'       => 1,
                 'color'        => 'FFFF00FF',
@@ -665,7 +665,7 @@ sub splash {
             {
                 'bounding_box' => TRUE,
                 'x'            => 0,
-                'y'            => (620 * $vf) + $Y,
+                'y'            => (651 * $vf) + $Y,
                 'height'       => 50   * $vf,
                 'wscale'       => 1,
                 'color'        => '00EE00FF',
@@ -683,7 +683,7 @@ sub splash {
                 {
                     'bounding_box' => TRUE,
                     'x'            => 0,
-                    'y'            => (730 * $vf) + $Y,
+                    'y'            => (771 * $vf) + $Y,
                     'height'       => 120  * $vf,
                     'wscale'       => 1,
                     'color'        => 'FFFFFFFF',
@@ -698,7 +698,7 @@ sub splash {
             {
                 'bounding_box' => TRUE,
                 'x'            => 0,
-                'y'            => (860 * $vf) + $Y,
+                'y'            => (901 * $vf) + $Y,
                 'height'       => 120  * $vf,
                 'wscale'       => 1,
                 'color'        => 'FFFFFFFF',
